# Version history

## 0.12.8

- Bump trio upper version to <0.29.

## 0.12.7

- Add `pycrdt.__version__`.
- Use PyPI's trusted publishing.

## 0.12.4

- Upgrade `yrs` to v0.22.0.

## 0.12.3

- Upgrade `pyo3` to v0.23.4.

## 0.12.2

- Allow passing a Python timestamp function to an undo manager.

## 0.12.1

- Add `TypedArray` typed container.

## 0.12.0

- Add `TypedDoc` and `TypedMap` typed containers.

## 0.11.1

- Rearrange typing tests and docs.

## 0.11.0

- Drop Python v3.8.
- Support type annotations.

## 0.10.9

- Bump `pyo3` to v0.23.3.

## 0.10.8

- Fix `Array` iterator.

## 0.10.7

- Add support for adding `XmlFragments` to arrays and maps (PR by @ColonelThirtyTwo).

## 0.10.6

- Bump yrs v0.21.3 and pyo3 v0.22.5.

## 0.10.4

- Add `CHANGELOG.md` and automate release on tag.
- Add support for XML, Text attributes and embeds (#184) (PR by @ColonelThirtyTwo).

## 0.10.3
